@@ -1,21 +1,8 @@
 /* This file is part of the KDE project
-   Copyright (C) 2003 Joseph Wenninger <jowenn@kde.org>
-   Copyright (C) 2008 David Faure <faure@kde.org>
+   SPDX-FileCopyrightText: 2003 Joseph Wenninger <jowenn@kde.org>
+   SPDX-FileCopyrightText: 2008 David Faure <faure@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include <QDebug>
@@ -28,6 +15,13 @@
 
 #include <time.h>
 
+// Pseudo plugin class to embed meta data
+class KIOPluginForMetaData : public QObject
+{
+    Q_OBJECT
+    Q_PLUGIN_METADATA(IID "org.kde.kio.slave.settings" FILE "settings.json")
+};
+
 class SettingsProtocol : public KIO::SlaveBase
 {
 public:
@@ -213,3 +207,5 @@ void SettingsProtocol::get( const QUrl & url )
         error( KIO::ERR_IS_DIRECTORY, url.toDisplayString() );
     }
 }
+
+#include "kio_settings.moc"
